==> roundcubemail-1.3.0-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/nb_NO.js <==
tinymce.addI18n('nb_NO',{
"Cut": "Klipp ut",
"Heading 5": "Overskrift 5",
"Header 2": "Overskrift 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Nettleseren din st\u00f8tter ikke direkte tilgang til utklippsboken. Bruk istedet tastatur-snarveiene Ctrl+X\/C\/V, eller Cmd+X\/C\/V p\u00e5 Mac.",
"Heading 4": "Overskrift 4",
"Div": "Delblokk <div>",
"Heading 2": "Overskrift 2",
"Paste": "Lim inn",
"Close": "Lukk",
"Font Family": "Skriftsnitt",
"Pre": "Definert <pre>",
"Align right": "H\u00f8yrejustert",
"New document": "Nytt dokument",
"Blockquote": "Sitatblokk <blockquote>",
"Numbered list": "Nummerliste",
"Heading 1": "Overskrift 1",
"Headings": "Overskrifter",
"Increase indent": "\u00d8k innrykk",
"Formats": "Stiler",
"Headers": "Overskrifter",
"Select all": "Marker alt",
"Header 3": "Overskrift 3",
"Blocks": "Blokker",
"Undo": "Angre",
"Strikethrough": "Gjennomstreket",
"Bullet list": "Punktliste",
"Header 1": "Overskrift 1",
"Superscript": "Hevet skrift",
"Clear formatting": "Fjern formateringer",
"Font Sizes": "St\u00f8rrelse",
"Subscript": "Senket skrift",
"Header 6": "Overskrift 6",
"Redo": "Utf\u00f8r likevel",
"Paragraph": "Avsnitt <p>",
"Ok": "OK",
"Bold": "Halvfet",
"Code": "Kode <code>",
"Italic": "Kursiv",
"Align center": "Midtstilt",
"Header 5": "Overskrift 5",
"Heading 6": "Overskrift 6",
"Heading 3": "Overskrift 3",
"Decrease indent": "Reduser innrykk",
"Header 4": "Overskrift 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Lim inn er n\u00e5 i ren-tekst modus. Kopiert innhold vil bli limt inn som ren tekst inntil du sl\u00e5r av dette valget.",
"Underline": "Understreket",
"Cancel": "Avbryt",
"Justify": "Juster alle linjer",
"Inline": "Innkapslet <span>",
"Copy": "Kopier",
"Align left": "Venstrejustert",
"Visual aids": "Visuelle hjelpemidler",
"Lower Greek": "Greske minuskler",
"Square": "Fylt firkant",
"Default": "Normal",
"Lower Alpha": "Minuskler",
"Circle": "\u00c5pen sirkel",
"Disc": "Fylt sirkel",
"Upper Alpha": "Versaler",
"Upper Roman": "Romerske versaler",
"Lower Roman": "Romerske minuskler",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id burde starte med en bokstav, bare fulgt av bokstaver, nummer, streker, punktum, koloner eller understreker.",
"Name": "Navn",
"Anchor": "Anker",
"Id": "Id",
"You have unsaved changes are you sure you want to navigate away?": "Du har ikke arkivert endringene. Vil du fortsette uten \u00e5 arkivere?",
"Restore last draft": "Gjenopprett siste utkast",
"Special character": "Spesialtegn",
"Source code": "Kildekode",
"Language": "Spr\u00e5k",
"Insert\/Edit code sample": "Sett inn\/endre kodeeksempel",
"B": "B",
"R": "R",
"G": "G",
"Color": "Farge",
"Right to left": "H\u00f8yre til venstre",
"Left to right": "Venstre til h\u00f8yre",
"Emoticons": "Hum\u00f8rfjes",
"Robots": "Roboter",
"Document properties": "Dokumentegenskaper",
"Title": "Tittel",
"Keywords": "N\u00f8kkelord",
"Encoding": "Tegnkoding",
"Description": "Beskrivelse",
"Author": "Forfatter",
"Fullscreen": "Fullskjerm",
"Horizontal line": "Horisontal linje",
"Horizontal space": "Horisontal marg",
"Insert\/edit image": "Sett inn\/endre bilde",
"General": "Generelt",
"Advanced": "Avansert",
"Source": "Bildelenke",
"Border": "Ramme",
"Constrain proportions": "Behold proporsjoner",
"Vertical space": "Vertikal marg",
"Image description": "Bildebeskrivelse",
"Style": "Stil",
"Dimensions": "Dimensjoner",
"Insert image": "Sett inn bilde",
"Image": "Bilde",
"Zoom in": "Zoom inn",
"Contrast": "Kontrast",
"Back": "Tilbake",
"Gamma": "Gamma",
"Flip horizontally": "Speilvend horisontalt",
"Resize": "Skaler",
"Sharpen": "Skarphet",
"Zoom out": "Zoom ut",
"Image options": "Bilde innstillinger",
"Apply": "Utf\u00f8r",
"Brightness": "Lysstyrke",
"Rotate clockwise": "Roter mot h\u00f8yre",
"Rotate counterclockwise": "Roter mot venstre",
"Edit image": "Rediger bilde",
"Color levels": "Fargeniv\u00e5",
"Crop": "Beskj\u00e6r",
"Orientation": "Orientering",
"Flip vertically": "Speilvend vertikalt",
"Invert": "Inverter",
"Date\/time": "Dato\/tid",
"Insert date\/time": "Sett inn dato\/tid",
"Remove link": "Fjern lenke",
"Url": "Url",
"Text to display": "Tekst som skal vises",
"Anchors": "Anker",
"Insert link": "Sett inn lenke",
"Link": "Lenke",
"New window": "Nytt vindu",
"None": "Ingen",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Oppgitt URL ser ut til \u00e5 v\u00e6re en e-postadresse. \u00d8nsker du \u00e5 sette inn p\u00e5krevd mailto:-prefiks foran e-postadressen?",
"Paste or type a link": "Lim inn eller skriv en lenke",
"Target": "M\u00e5l",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Oppgitte URL ser ut til \u00e5 v\u00e6re en epost-adresse. \u00d8nsker du \u00e5 sette inn p\u00e5krevet mailto: prefiks forran epost-adressen?",
"Insert\/edit link": "Sett inn\/endre lenke",
"Insert\/edit video": "Sett inn\/rediger video",
"Media": "Media",
"Alternative source": "Alternativ kilde",
"Paste your embed code below:": "Lim inn  inkluderings-koden nedenfor",
"Insert video": "Sett inn video",
"Poster": "Plakatbilde",
"Insert\/edit media": "Sett inn\/endre media",
"Embed": "Inkluder",
"Nonbreaking space": "Hardt mellomrom",
"Page break": "Sideskifte",
"Paste as text": "Lim inn som tekst",
"Preview": "Forh\u00e5ndsvisning",
"Print": "Skriv ut",
"Save": "Arkiver",
"Could not find the specified string.": "Kunne ikke finne den spesifiserte teksten",
"Replace": "Erstatt",
"Next": "Neste",
"Whole words": "Hele ord",
"Find and replace": "Finn og erstatt",
"Replace with": "Erstatt med",
"Find": "Finn",
"Replace all": "Erstatt alle",
"Match case": "Match store og sm\u00e5 bokstaver",
"Prev": "Forrige",
"Spellcheck": "Stavekontroll",
"Finish": "Avslutt",
"Ignore all": "Ignorer alle",
"Ignore": "Ignorer",
"Add to Dictionary": "Legg til i ordliste",
"Insert row before": "Sett inn rad f\u00f8r",
"Rows": "Rader",
"Height": "H\u00f8yde",
"Paste row after": "Lim inn rad etter",
"Alignment": "Justering",
"Border color": "Rammefarge",
"Column group": "Kolonnegruppe",
"Row": "Rad",
"Insert column before": "Sett inn kolonne f\u00f8r",
"Split cell": "Splitt celle",
"Cell padding": "Cellemarg",
"Cell spacing": "Celleavstand",
"Row type": "Rad-type",
"Insert table": "Sett inn tabell",
"Body": "Br\u00f8dtekst",
"Caption": "Tittel",
"Footer": "Bunntekst",
"Delete row": "Slett rad",
"Paste row before": "Lim inn rad f\u00f8r",
"Scope": "Omfang",
"Delete table": "Slett tabell",
"H Align": "H Justering",
"Top": "Topp",
"Header cell": "Topptekst-celle",
"Column": "Kolonne",
"Row group": "Radgruppe",
"Cell": "Celle",
"Middle": "Midten",
"Cell type": "Celletype",
"Copy row": "Kopier rad",
"Row properties": "Rad egenskaper",
"Table properties": "Tabell egenskaper",
"Bottom": "Bunn",
"V Align": "V Justering",
"Header": "Topptekst",
"Right": "H\u00f8yre",
"Insert column after": "Sett inn kolonne etter",
"Cols": "Kolonner",
"Insert row after": "Sett in rad etter",
"Width": "Bredde",
"Cell properties": "Celle egenskaper",
"Left": "Venstre",
"Cut row": "Klipp ut rad",
"Delete column": "Slett kolonne",
"Center": "Midtstilt",
"Merge cells": "Sl\u00e5 sammen celler",
"Insert template": "Sett inn mal",
"Templates": "Maler",
"Background color": "Bakgrunnsfarge",
"Custom...": "Tilpass...",
"Custom color": "Tilpasset farge",
"No color": "Ingen farge",
"Text color": "Tekstfarge",
"Table of Contents": "Innholdsfortegnelse",
"Show blocks": "Vis blokker",
"Show invisible characters": "Vis skjulte tegn",
"Words: {0}": "Antall ord: {0}",
"Insert": "Sett inn",
"File": "Arkiv",
"Edit": "Rediger",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Tekstredigering. Tast ALT-F9 for meny. Tast ALT-F10 for verkt\u00f8ys-rader. Tast ALT-0 for hjelp.",
"Tools": "Verkt\u00f8y",
"View": "Vis",
"Table": "Tabell",
"Format": "Format"
});

==> roundcubemail-1.3.3-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/nb_NO.js <==
tinymce.addI18n('nb_NO',{
"Redo": "Utf\u00f8r likevel",
"Undo": "Angre",
"Cut": "Klipp ut",
"Copy": "Kopier",
"Paste": "Lim inn",
"Select all": "Marker alt",
"New document": "Nytt dokument",
"Ok": "OK",
"Cancel": "Avbryt",
"Visual aids": "Visuelle hjelpemidler",
"Bold": "Halvfet",
"Italic": "Kursiv",
"Underline": "Understreket",
"Strikethrough": "Gjennomstreket",
"Superscript": "Hevet skrift",
"Subscript": "Senket skrift",
"Clear formatting": "Fjern formateringer",
"Align left": "Venstrejustert",
"Align center": "Midtstilt",
"Align right": "H\u00f8yrejustert",
"Justify": "Juster alle linjer",
"Bullet list": "Punktliste",
"Numbered list": "Nummerliste",
"Decrease indent": "Reduser innrykk",
"Increase indent": "\u00d8k innrykk",
"Close": "Lukk",
"Formats": "Stiler",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Nettleseren din st\u00f8tter ikke direkte tilgang til utklippsboken. Bruk istedet tastatur-snarveiene Ctrl+X\/C\/V, eller Cmd+X\/C\/V p\u00e5 Mac.",
"Headers": "Overskrifter",
"Header 1": "Overskrift 1",
"Header 2": "Overskrift 2",
"Header 3": "Overskrift 3",
"Header 4": "Overskrift 4",
"Header 5": "Overskrift 5",
"Header 6": "Overskrift 6",
"Headings": "Overskrifter",
"Heading 1": "Overskrift 1",
"Heading 2": "Overskrift 2",
"Heading 3": "Overskrift 3",
"Heading 4": "Overskrift 4",
"Heading 5": "Overskrift 5",
"Heading 6": "Overskrift 6",
"Div": "Delblokk <div>",
"Pre": "Definert <pre>",
"Code": "Kode <code>",
"Paragraph": "Avsnitt <p>",
"Blockquote": "Sitatblokk <blockquote>",
"Inline": "Innkapslet <span>",
"Blocks": "Blokker",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Lim inn er n\u00e5 i ren-tekst modus. Kopiert innhold vil bli limt inn som ren tekst inntil du sl\u00e5r av dette valget.",
"Font Family": "Skriftsnitt",
"Font Sizes": "St\u00f8rrelse",
"Class": "Klasse",
"Browse for an image": "S\u00f8k etter bilde",
"OR": "ELLER",
"Drop an image here": "Slipp et bilde her",
"Upload": "Last opp",
"Default": "Normal",
"Circle": "\u00c5pen sirkel",
"Disc": "Fylt sirkel",
"Square": "Fylt firkant",
"Lower Alpha": "Minuskler",
"Lower Greek": "Greske minuskler",
"Lower Roman": "Romerske minuskler",
"Upper Alpha": "Versaler",
"Upper Roman": "Romerske versaler",
"Anchor": "Anker",
"Name": "Navn",
"Id": "Id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id burde starte med en bokstav, bare fulgt av bokstaver, nummer, streker, punktum, koloner eller understreker.",
"You have unsaved changes are you sure you want to navigate away?": "Du har ikke arkivert endringene. Vil du fortsette uten \u00e5 arkivere?",
"Restore last draft": "Gjenopprett siste utkast",
"Special character": "Spesialtegn",
"Source code": "Kildekode",
"Insert\/Edit code sample": "Sett inn\/endre kodeeksempel",
"Language": "Spr\u00e5k",
"Color": "Farge",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Venstre til h\u00f8yre",
"Right to left": "H\u00f8yre til venstre",
"Emoticons": "Hum\u00f8rfjes",
"Document properties": "Dokumentegenskaper",
"Title": "Tittel",
"Keywords": "N\u00f8kkelord",
"Description": "Beskrivelse",
"Robots": "Roboter",
"Author": "Forfatter",
"Encoding": "Tegnkoding",
"Fullscreen": "Fullskjerm",
"Action": "Handling",
"Shortcut": "Snarvei",
"Help": "Hjelp",
"Address": "Adresse",
"Focus to menubar": "Fokus p\u00e5 menylinje",
"Focus to toolbar": "Fokus p\u00e5 verkt\u00f8ylinje",
"Focus to element path": "Fokus p\u00e5 elementsti",
"Focus to contextual toolbar": "Fokus p\u00e5 kontekstuell verkt\u00f8ylinje",
"Insert link (if link plugin activated)": "Sett inn lenke (dersom lenketillegg er aktivert)",
"Save (if save plugin activated)": "Lagre (dersom lagretillegg er aktivert)",
"Find (if searchreplace plugin activated)": "Finn (dersom tillegg for s\u00f8k og erstatt er aktivert)",
"Plugins installed ({0}):": "Installerte tillegg ({0}):",
"Premium plugins:": "Premiumtillegg:",
"Learn more...": "Les mer ...",
"You are using {0}": "Du bruker {0}",
"Horizontal line": "Horisontal linje",
"Insert\/edit image": "Sett inn\/endre bilde",
"Image description": "Bildebeskrivelse",
"Source": "Bildelenke",
"Dimensions": "Dimensjoner",
"Constrain proportions": "Behold proporsjoner",
"General": "Generelt",
"Advanced": "Avansert",
"Style": "Stil",
"Vertical space": "Vertikal marg",
"Horizontal space": "Horisontal marg",
"Border": "Ramme",
"Insert image": "Sett inn bilde",
"Image": "Bilde",
"Image list": "Bildeliste",
"Rotate counterclockwise": "Roter mot venstre",
"Rotate clockwise": "Roter mot h\u00f8yre",
"Flip vertically": "Speilvend vertikalt",
"Flip horizontally": "Speilvend horisontalt",
"Edit image": "Rediger bilde",
"Image options": "Bilde innstillinger",
"Zoom in": "Zoom inn",
"Zoom out": "Zoom ut",
"Crop": "Beskj\u00e6r",
"Resize": "Skaler",
"Orientation": "Orientering",
"Brightness": "Lysstyrke",
"Sharpen": "Skarphet",
"Contrast": "Kontrast",
"Color levels": "Fargeniv\u00e5",
"Gamma": "Gamma",
"Invert": "Inverter",
"Apply": "Utf\u00f8r",
"Back": "Tilbake",
"Insert date\/time": "Sett inn dato\/tid",
"Date\/time": "Dato\/tid",
"Insert link": "Sett inn lenke",
"Insert\/edit link": "Sett inn\/endre lenke",
"Text to display": "Tekst som skal vises",
"Url": "Url",
"Target": "M\u00e5l",
"None": "Ingen",
"New window": "Nytt vindu",
"Remove link": "Fjern lenke",
"Anchors": "Anker",
"Link": "Lenke",
"Paste or type a link": "Lim inn eller skriv en lenke",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Oppgitte URL ser ut til \u00e5 v\u00e6re en epost-adresse. \u00d8nsker du \u00e5 sette inn p\u00e5krevet mailto: prefiks forran epost-adressen?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Oppgitt URL ser ut til \u00e5 v\u00e6re en e-postadresse. \u00d8nsker du \u00e5 sette inn p\u00e5krevd mailto:-prefiks foran e-postadressen?",
"Link list": "Lenkeliste",
"Insert video": "Sett inn video",
"Insert\/edit video": "Sett inn\/rediger video",
"Insert\/edit media": "Sett inn\/endre media",
"Alternative source": "Alternativ kilde",
"Poster": "Plakatbilde",
"Paste your embed code below:": "Lim inn  inkluderings-koden nedenfor",
"Embed": "Inkluder",
"Media": "Media",
"Nonbreaking space": "Hardt mellomrom",
"Page break": "Sideskifte",
"Paste as text": "Lim inn som tekst",
"Preview": "Forh\u00e5ndsvisning",
"Print": "Skriv ut",
"Save": "Arkiver",
"Find": "Finn",
"Replace with": "Erstatt med",
"Replace": "Erstatt",
"Replace all": "Erstatt alle",
"Prev": "Forrige",
"Next": "Neste",
"Find and replace": "Finn og erstatt",
"Could not find the specified string.": "Kunne ikke finne den spesifiserte teksten",
"Match case": "Match store og sm\u00e5 bokstaver",
"Whole words": "Hele ord",
"Spellcheck": "Stavekontroll",
"Ignore": "Ignorer",
"Ignore all": "Ignorer alle",
"Finish": "Avslutt",
"Add to Dictionary": "Legg til i ordliste",
"Insert table": "Sett inn tabell",
"Table properties": "Tabell egenskaper",
"Delete table": "Slett tabell",
"Cell": "Celle",
"Row": "Rad",
"Column": "Kolonne",
"Cell properties": "Celle egenskaper",
"Merge cells": "Sl\u00e5 sammen celler",
"Split cell": "Splitt celle",
"Insert row before": "Sett inn rad f\u00f8r",
"Insert row after": "Sett in rad etter",
"Delete row": "Slett rad",
"Row properties": "Rad egenskaper",
"Cut row": "Klipp ut rad",
"Copy row": "Kopier rad",
"Paste row before": "Lim inn rad f\u00f8r",
"Paste row after": "Lim inn rad etter",
"Insert column before": "Sett inn kolonne f\u00f8r",
"Insert column after": "Sett inn kolonne etter",
"Delete column": "Slett kolonne",
"Cols": "Kolonner",
"Rows": "Rader",
"Width": "Bredde",
"Height": "H\u00f8yde",
"Cell spacing": "Celleavstand",
"Cell padding": "Cellemarg",
"Caption": "Tittel",
"Left": "Venstre",
"Center": "Midtstilt",
"Right": "H\u00f8yre",
"Cell type": "Celletype",
"Scope": "Omfang",
"Alignment": "Justering",
"H Align": "H Justering",
"V Align": "V Justering",
"Top": "Topp",
"Middle": "Midten",
"Bottom": "Bunn",
"Header cell": "Topptekst-celle",
"Row group": "Radgruppe",
"Column group": "Kolonnegruppe",
"Row type": "Rad-type",
"Header": "Topptekst",
"Body": "Br\u00f8dtekst",
"Footer": "Bunntekst",
"Border color": "Rammefarge",
"Insert template": "Sett inn mal",
"Templates": "Maler",
"Template": "Mal",
"Text color": "Tekstfarge",
"Background color": "Bakgrunnsfarge",
"Custom...": "Tilpass...",
"Custom color": "Tilpasset farge",
"No color": "Ingen farge",
"Table of Contents": "Innholdsfortegnelse",
"Show blocks": "Vis blokker",
"Show invisible characters": "Vis skjulte tegn",
"Words: {0}": "Antall ord: {0}",
"File": "Arkiv",
"Edit": "Rediger",
"Insert": "Sett inn",
"View": "Vis",
"Format": "Format",
"Table": "Tabell",
"Tools": "Verkt\u00f8y",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Tekstredigering. Tast ALT-F9 for meny. Tast ALT-F10 for verkt\u00f8ys-rader. Tast ALT-0 for hjelp."
});
